//-----------------------------------------------------------------------
// Macro: DELWORD
//
// Function:
//
//   This macro deletes the word at the current curspr position and
//   the blank which follows it (if any).
//
// NOTE: Most example macros provide trivial functionality. Their primary
// purpose is to show a variety of coding techniques.
//-----------------------------------------------------------------------
void delword(void) {
 
  char *text;
   
  int   col;
  int   col_start, col_end;
  int   line_length;
  int   word_length;
   
  text = SPFservice("query","line_data");          // get current line text
  col = SPFservice("query","col_number");          // get current data column number
  line_length = SPFservice("query","line_length"); // get current line length
  if (text && col >= 1 && col <= line_length) {
    while (col > 1 && StrGetSubstr(text,col,1) != " ") --col; // back up to blank
    if (StrGetSubstr(text,col,1) == " ") ++col;    // step over blank
    col_start = col;                               // save for later
    col_end = StrFindSubstr(text," ",col_start);   // find next blank
    if (col_end > col_start) {
      //-------------
      // "word" found
      //-------------
      word_length = (col_end - col_start) + 1;     // word length
      }
    else {
      //---------------------------------------------------------------
      // "word" not found, make "word" = preceding blank to end of line
      //---------------------------------------------------------------
      if (col_start > 1) --col_start;              // back up over preceding blank
      col_end = line_length;
      word_length = (col_end - col_start) + 1;     // word length
    }
    //--------------
    // delete "word"
    //--------------
    StrDelSubstr(text,col_start,word_length);
    //----------------------------
    // update line content in Edit
    //----------------------------
    SPFservice("set","line_data",text);
    SPFservice("set","col_number",col_start);
    }
  else {
    Msg("DELWORD: no word at current cursor position.");
  }

} // delword
